version 9.2

* This file assumes that the file "create correlations.do" has already been run. This puts correlations with Citi into an output file called "citicorr.dta".
* This file assumes that the file "create residuals.do" has already been run. The output file "residuals.dta" allows calculation of adjusted standard errors.
* This file assumes that the file "Geithner event study.do" has already been run.  This puts abnormal returns into an output file called "Event Study Output.dta".
* This file assumes that the file "Geithner event study Lehman.do" has already been run.  This puts abnormal returns surrounding Lehman collapse into an output file called "Event Study Output Lehman.dta".
* This file assumes that the file "Geithner event study Paulson.do" has already been run.  This puts abnormal returns surrounding Paulson's gift into an output file called "Event Study Output Paulson.dta".
* This file assumes that the file "Geithner event study short.do" has already been run.  This puts abnormal returns based on shorter estimation window into an output file called "Event Study Output short.dta".

set more off

local path "E:\Bank Crisis\"   /*insert local path of the folder used here */
cd "`path'"


* CONTROL FOR CRISIS VULNERABILITY (Columns 1 and 2)


* merge in abnormal returns from the Lehman collapse event

use "Event Study Output Lehman.dta", clear
keep ticker CAR0to4
rename CAR0to4 CAR0to4_lmn
sort ticker
save "merge.dta", replace


* merge in personal connections data

use "Connections Data.dta", clear
gen PERSONAL_CONNECTIONS____________=.

label var PERSONAL_CONNECTIONS____________ "_____from muckety.com

save "Master Data.dta", replace


* merge in schedule connections data

use "Schedule Data.dta", clear
sort ticker
save "Schedule Data.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Schedule Data.dta"
drop if _merge==2
drop _merge
gen SCHEDULE_CONNECTIONS____________=.
move SCHEDULE_CONNECTIONS____________ geithnerschednum
label var SCHEDULE_CONNECTIONS____________ "_____from geithner2numT-posted schedule

save "Master Data.dta", replace


* merge in TARP data

use "TARP Data.dta", clear
sort ticker
save "TARP Data.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "TARP Data.dta"
drop if _merge==2
drop _merge
gen TARP_DATA_______________________=.
move  TARP_DATA_______________________ footnote_tarp
label var TARP_DATA_______________________ "_____from US Treasury Dept.
replace amount_tarp=0 if amount_tarp==.
drop if footnote_tarp==0     /* this gets rid of multiple tarp funding dates */

save "Master Data.dta", replace


* merge in event study results

use "Event Study Output.dta", clear
sort ticker
save "Event Study Output.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Event Study Output.dta"
drop if _merge==2
drop _merge
gen GEITHNER_ANNC_RETURNS___________=.
move GEITHNER_ANNC_RETURNS___________ index_ds
label var GEITHNER_ANNC_RETURNS___________ "_____from Datastream returns

drop if ret0==. /* eliminates firms missing TAQ data */

save "Master Data.dta", replace 


* merge in financial data

use "Financial Data.dta", clear
sort ticker
save "Financial Data.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Financial Data.dta", update
drop if _merge==2
drop _merge

replace roe2008=. if roe2008>1000   /* eliminate outliers */
replace tdtc2008=. if tdtc2008<0    /* eliminate outliers */
replace ta2008=ta2008*1000          /* puts in $ terms */
replace mcap2008=mcap2008*1000      /* puts in $ terms */
gen ta2008_log=log(ta2008)
move ta2008_log roe2008
label var ta2008_log "log of ta2008
replace roe2008=roe2008/100         /* puts in percentage terms */
replace tdtc2008=tdtc2008/100       /* puts in percentage terms */

gen FINANCIAL_DATA__________________=.
move FINANCIAL_DATA__________________ name
label var FINANCIAL_DATA__________________ "_____from Worldscope



save "Master Data.dta", replace

sort ticker
merge ticker using "merge.dta"
drop if _merge==2
drop _merge

sort ticker
merge ticker using "citicorr.dta"
drop if _merge==2
drop _merge

* Create additional control variables

gen statadate_tarp=date(datestring_tarp,"md20y")
gen tarpbefore=0
replace tarpbefore=1 if ~(amount_tarp==0) & statadate_tarp<17857 & ~(statadate_tarp==.) /* dummy for if firm had received TARP funding prior to nomination */

gen dep=0
replace dep=1 if  tdep2ta2008>0 &~( tdep2ta2008==.)
replace dep=1 if dep==0 &  tdep2ta2007>0 &~( tdep2ta2007==.) & ~( tdep2ta2008==0)  /*  dummy for if the firm takes deposits */

gen ta2008_log_sq=ta2008_log^2
gen ta2008_log_cb=(ta2008_log^3)

gen roe2008_sq=roe2008^2
gen roe2008_cb=(roe2008^3)

gen tdtc2008_sq=tdtc2008^2
gen tdtc2008_cb=(tdtc2008^3)

gen constant=1
sort ticker
merge ticker using "residuals.dta"
drop if _merge==2
drop _merge

reg abnormal_return0 geithnerschednum  ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  CAR0to4_lmn dep tarpbefore ,   robust


putmata Y=abnormal_return0 X=(geithnerschednum  ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  CAR0to4_lmn dep tarpbefore constant) Err=(residbaseone*) , omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end


reg abnormal_return0 geithner2num  ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  CAR0to4_lmn dep tarpbefore ,   robust


putmata Y=abnormal_return0 X=(geithner2num  ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  CAR0to4_lmn dep tarpbefore constant) Err=(residbaseone*) , omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end

reg CAR0to1 geithnerschednum  ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  CAR0to4_lmn dep tarpbefore if citicorr<=citicorr_90th,   robust

putmata Y=CAR0to1 X=(geithnerschednum  ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  CAR0to4_lmn dep tarpbefore constant) Err=(residbasetwo*) if citicorr<=citicorr_90th, omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end


reg CAR0to1 geithner2num  ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  CAR0to4_lmn dep tarpbefore if citicorr<=citicorr_90th,   robust

putmata Y=CAR0to1 X=(geithner2num  ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  CAR0to4_lmn dep tarpbefore constant) Err=(residbasetwo*) if citicorr<=citicorr_90th, omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end

reg CAR0to10 geithnerschednum  ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  CAR0to4_lmn dep tarpbefore if citicorr<=citicorr_90th,   robust

putmata Y=CAR0to10 X=(geithnerschednum  ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  CAR0to4_lmn dep tarpbefore constant) Err=(residbaseten*)  if  citicorr<=citicorr_90th, omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end


reg CAR0to10 geithner2num  ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  CAR0to4_lmn dep tarpbefore if citicorr<=citicorr_90th,   robust

putmata Y=CAR0to10 X=(geithner2num  ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  CAR0to4_lmn dep tarpbefore constant) Err=(residbaseten*)  if  citicorr<=citicorr_90th, omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end


* CONTROL FOR "PAULSON'S GIFT" EVENT (Columns 3 and 4)


* merge in abnormal returns from the Paulson's Gift event

use "Event Study Output Paulson.dta", clear
keep ticker CAR0to1
rename CAR0to1 CAR0to1_pg
sort ticker
save "merge.dta", replace


* merge in personal connections data

use "Connections Data.dta", clear
gen PERSONAL_CONNECTIONS____________=.

label var PERSONAL_CONNECTIONS____________ "_____from muckety.com

save "Master Data.dta", replace


* merge in schedule connections data

use "Schedule Data.dta", clear
sort ticker
save "Schedule Data.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Schedule Data.dta"
drop if _merge==2
drop _merge
gen SCHEDULE_CONNECTIONS____________=.
move SCHEDULE_CONNECTIONS____________ geithnerschednum
label var SCHEDULE_CONNECTIONS____________ "_____from geithner2numT-posted schedule

save "Master Data.dta", replace


* merge in TARP data

use "TARP Data.dta", clear
sort ticker
save "TARP Data.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "TARP Data.dta"
drop if _merge==2
drop _merge
gen TARP_DATA_______________________=.
move  TARP_DATA_______________________ footnote_tarp
label var TARP_DATA_______________________ "_____from US Treasury Dept.
replace amount_tarp=0 if amount_tarp==.
drop if footnote_tarp==0     /* this gets rid of multiple tarp funding dates */

save "Master Data.dta", replace


* merge in event study results

use "Event Study Output.dta", clear
sort ticker
save "Event Study Output.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Event Study Output.dta"
drop if _merge==2
drop _merge
gen GEITHNER_ANNC_RETURNS___________=.
move GEITHNER_ANNC_RETURNS___________ index_ds
label var GEITHNER_ANNC_RETURNS___________ "_____from Datastream returns

drop if ret0==. /* eliminates firms missing TAQ data */

save "Master Data.dta", replace 


* merge in financial data

use "Financial Data.dta", clear
sort ticker
save "Financial Data.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Financial Data.dta", update
drop if _merge==2
drop _merge

replace roe2008=. if roe2008>1000   /* eliminate outliers */
replace tdtc2008=. if tdtc2008<0    /* eliminate outliers */
replace ta2008=ta2008*1000          /* puts in $ terms */
replace mcap2008=mcap2008*1000      /* puts in $ terms */
gen ta2008_log=log(ta2008)
move ta2008_log roe2008
label var ta2008_log "log of ta2008
replace roe2008=roe2008/100         /* puts in percentage terms */
replace tdtc2008=tdtc2008/100       /* puts in percentage terms */


gen ta2008_log_sq=ta2008_log^2
gen ta2008_log_cb=(ta2008_log^3)

gen roe2008_sq=roe2008^2
gen roe2008_cb=(roe2008^3)

gen tdtc2008_sq=tdtc2008^2
gen tdtc2008_cb=(tdtc2008^3)


gen FINANCIAL_DATA__________________=.
move FINANCIAL_DATA__________________ name
label var FINANCIAL_DATA__________________ "_____from Worldscope


save "Master Data.dta", replace

sort ticker
merge ticker using "merge.dta"
drop if _merge==2
drop _merge

sort ticker
merge ticker using "citicorr.dta"
drop if _merge==2
drop _merge

* Create additional control variables

gen statadate_tarp=date(datestring_tarp,"md20y")
gen tarpbefore=0
replace tarpbefore=1 if ~(amount_tarp==0) & statadate_tarp<17857 & ~(statadate_tarp==.) /* dummy for if firm had received TARP funding prior to nomination */

gen dep=0
replace dep=1 if  tdep2ta2008>0 &~( tdep2ta2008==.)
replace dep=1 if dep==0 &  tdep2ta2007>0 &~( tdep2ta2007==.) & ~( tdep2ta2008==0)  /*  dummy for if the firm takes deposits */

gen constant=1
sort ticker
merge ticker using "residuals.dta"
drop if _merge==2
drop _merge

reg abnormal_return0 geithnerschednum  ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  CAR0to1_pg ,   robust


putmata Y=abnormal_return0 X=(geithnerschednum  ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb   CAR0to1_pg  constant) Err=(residbaseone*) , omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end


reg abnormal_return0 geithner2num  ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb   CAR0to1_pg ,   robust


putmata Y=abnormal_return0 X=(geithner2num  ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb   CAR0to1_pg  constant) Err=(residbaseone*) , omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end

reg CAR0to1 geithnerschednum  ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb   CAR0to1_pg  if citicorr<=citicorr_90th,   robust

putmata Y=CAR0to1 X=(geithnerschednum  ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb   CAR0to1_pg  constant) Err=(residbasetwo*) if citicorr<=citicorr_90th, omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end


reg CAR0to1 geithner2num  ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb   CAR0to1_pg  if citicorr<=citicorr_90th,   robust

putmata Y=CAR0to1 X=(geithner2num  ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb   CAR0to1_pg  constant) Err=(residbasetwo*) if citicorr<=citicorr_90th, omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end

reg CAR0to10 geithnerschednum  ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb   CAR0to1_pg  if citicorr<=citicorr_90th,   robust

putmata Y=CAR0to10 X=(geithnerschednum  ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb   CAR0to1_pg  constant) Err=(residbaseten*)  if  citicorr<=citicorr_90th, omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end


reg CAR0to10 geithner2num  ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb   CAR0to1_pg  if citicorr<=citicorr_90th,   robust

putmata Y=CAR0to10 X=(geithner2num  ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb   CAR0to1_pg  constant) Err=(residbaseten*)  if  citicorr<=citicorr_90th, omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end



*  LEHMAN COLLAPSE ESTIMATION BETA (Columns 5 and 6)


* merge in personal connections data

use "Connections Data.dta", clear
gen PERSONAL_CONNECTIONS____________=.

label var PERSONAL_CONNECTIONS____________ "_____from muckety.com

save "Master Data.dta", replace


* merge in schedule connections data

use "Schedule Data.dta", clear
sort ticker
save "Schedule Data.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Schedule Data.dta"
drop if _merge==2
drop _merge
gen SCHEDULE_CONNECTIONS____________=.
move SCHEDULE_CONNECTIONS____________ geithnerschednum
label var SCHEDULE_CONNECTIONS____________ "_____from geithner2numT-posted schedule

save "Master Data.dta", replace


* merge in event study results

use "Event Study Output short.dta", clear
sort ticker
save "Event Study Output short.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Event Study Output short.dta"
drop if _merge==2
drop _merge
gen GEITHNER_ANNC_RETURNS___________=.
move GEITHNER_ANNC_RETURNS___________ index_ds
label var GEITHNER_ANNC_RETURNS___________ "_____from Datastream returns
drop if ret0==. /* this excludes firms that are missing TAQ data */

save "Master Data.dta", replace 


* merge in financial data

use "Financial Data.dta", clear
sort ticker
save "Financial Data.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Financial Data.dta", update
drop if _merge==2
drop _merge

replace roe2008=. if roe2008>1000   /* eliminate outliers */
replace tdtc2008=. if tdtc2008<0    /* eliminate outliers */
replace ta2008=ta2008*1000          /* puts in $ terms */
replace mcap2008=mcap2008*1000      /* puts in $ terms */
gen ta2008_log=log(ta2008)
move ta2008_log roe2008
label var ta2008_log "log of ta2008
replace roe2008=roe2008/100         /* puts in percentage terms */
replace tdtc2008=tdtc2008/100       /* puts in percentage terms */

gen FINANCIAL_DATA__________________=.
move FINANCIAL_DATA__________________ name
label var FINANCIAL_DATA__________________ "_____from Worldscope


gen ta2008_log_sq=ta2008_log^2
gen ta2008_log_cb=(ta2008_log^3)

gen roe2008_sq=roe2008^2
gen roe2008_cb=(roe2008^3)

gen tdtc2008_sq=tdtc2008^2
gen tdtc2008_cb=(tdtc2008^3)


sort ticker
merge ticker using "citicorr.dta"
drop if _merge==2
drop _merge
gen constant=1
sort ticker
merge ticker using "residuals.dta"
drop if _merge==2
drop _merge

reg abnormal_return0 geithnerschednum   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb   if fullsample==1, robust

putmata Y=abnormal_return0 X=(geithnerschednum   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  constant) Err=(residbaseone*) if fullsample==1, omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end


reg abnormal_return0 geithner2num   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb   if fullsample==1, robust

putmata Y=abnormal_return0 X=(geithner2num   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  constant) Err=(residbaseone*) if fullsample==1, omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end

reg CAR0to1 geithnerschednum   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb   if citicorr<=citicorr_90th & fullsample==1, robust

putmata Y=CAR0to1 X=(geithnerschednum   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  constant) Err=(residbasetwo*) if citicorr<=citicorr_90th & fullsample==1, omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end


reg CAR0to1 geithner2num   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb   if citicorr<=citicorr_90th & fullsample==1, robust

putmata Y=CAR0to1 X=(geithner2num   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  constant) Err=(residbasetwo*) if citicorr<=citicorr_90th & fullsample==1, omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end

reg CAR0to10 geithnerschednum   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb   if citicorr<=citicorr_90th & fullsample==1, robust

putmata Y=CAR0to10 X=(geithnerschednum   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  constant) Err=(residbaseten*)  if  citicorr<=citicorr_90th & fullsample==1, omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end


reg CAR0to10 geithner2num   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb   if citicorr<=citicorr_90th & fullsample==1, robust

putmata Y=CAR0to10 X=(geithner2num   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  constant) Err=(residbaseten*)  if  citicorr<=citicorr_90th & fullsample==1, omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end



*  CONTROL FOR TOXIC ASSETS (Columns 7 and 8)


* merge in personal connections data

use "Connections Data.dta", clear
gen PERSONAL_CONNECTIONS____________=.

label var PERSONAL_CONNECTIONS____________ "_____from muckety.com
move PERSONAL_CONNECTIONS____________ geithner2num
save "Master Data.dta", replace


* merge in schedule connections data

use "Schedule Data.dta", clear
sort ticker
save "Schedule Data.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Schedule Data.dta"
drop if _merge==2
drop _merge
gen SCHEDULE_CONNECTIONS____________=.
move SCHEDULE_CONNECTIONS____________ geithnerschednum
label var SCHEDULE_CONNECTIONS____________ "_____from NYT-posted schedule

save "Master Data.dta", replace


* merge in event study results

use "Event Study Output.dta", clear
sort ticker
save "Event Study Output.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Event Study Output.dta"
drop if _merge==2
drop _merge
gen GEITHNER_ANNC_RETURNS___________=.
move GEITHNER_ANNC_RETURNS___________ index_ds
label var GEITHNER_ANNC_RETURNS___________ "_____from Datastream returns

drop if ret0==. /* eliminates firms missing TAQ data */

save "Master Data.dta", replace 


* merge in financial data

use "Financial Data.dta", clear
sort ticker
save "Financial Data.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Financial Data.dta", update
drop if _merge==2
drop _merge

replace roe2008=. if roe2008>1000   /* eliminate outliers */
replace tdtc2008=. if tdtc2008<0    /* eliminate outliers */
replace ta2008=ta2008*1000          /* puts in $ terms */
replace mcap2008=mcap2008*1000      /* puts in $ terms */
gen ta2008_log=log(ta2008)
move ta2008_log roe2008
label var ta2008_log "log of ta2008
replace roe2008=roe2008/100         /* puts in percentage terms */
replace tdtc2008=tdtc2008/100       /* puts in percentage terms */


gen ta2008_log_sq=ta2008_log^2
gen ta2008_log_cb=(ta2008_log^3)

gen roe2008_sq=roe2008^2
gen roe2008_cb=(roe2008^3)

gen tdtc2008_sq=tdtc2008^2
gen tdtc2008_cb=(tdtc2008^3)

gen FINANCIAL_DATA__________________=.
move FINANCIAL_DATA__________________ name
label var FINANCIAL_DATA__________________ "_____from Worldscope



sort ticker
merge ticker using "citicorr.dta"
label variable citicorr "return correlation with Citigroup
label variable citicorr_90th "90th percentile in Citi correlation
drop if _merge==2
drop _merge
gen constant=1
sort ticker
merge ticker using "residuals.dta"
drop if _merge==2
drop _merge

sort ticker
merge ticker using  "Toxic Asset Data.dta"
drop if _merge==2
drop _merge

reg abnormal_return0 geithnerschednum   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  toxic_assets , robust

putmata Y=abnormal_return0 X=(geithnerschednum   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  toxic_assets  constant) Err=(residbaseone*)  , omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end


reg abnormal_return0 geithner2num   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb   toxic_assets  , robust

putmata Y=abnormal_return0 X=(geithner2num   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb   toxic_assets constant) Err=(residbaseone*)  , omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end


reg CAR0to1 geithnerschednum   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  toxic_assets  , robust

putmata Y=CAR0to1 X=(geithnerschednum   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  toxic_assets  constant) Err=(residbasetwo*)  , omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end


reg CAR0to1 geithner2num   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb   toxic_assets , robust

putmata Y=CAR0to1 X=(geithner2num   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  toxic_assets  constant) Err=(residbasetwo*) , omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end


reg CAR0to10 geithnerschednum   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  toxic_assets , robust

putmata Y=CAR0to10 X=(geithnerschednum   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  toxic_assets  constant) Err=(residbaseten*)  , omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end


reg CAR0to10 geithner2num   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  toxic_assets  , robust

putmata Y=CAR0to10 X=(geithner2num   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb   toxic_assets constant) Err=(residbaseten*) , omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end



*  EXCLUDE EXTREME CARS (Columns 9 and 10)

quietly summ abnormal_return0 , detail
gen CAR_1st=r(p1)
gen CAR_99th=r(p99)

reg abnormal_return0 geithnerschednum   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  if abnormal_return0>=CAR_1st & abnormal_return0<=CAR_99th , robust

putmata Y=abnormal_return0 X=(geithnerschednum   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  constant) Err=(residbaseone*)  if abnormal_return0>=CAR_1st & abnormal_return0<=CAR_99th , omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end


reg abnormal_return0 geithner2num   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  if abnormal_return0>=CAR_1st & abnormal_return0<=CAR_99th , robust

putmata Y=abnormal_return0 X=(geithner2num   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  constant) Err=(residbaseone*) if abnormal_return0>=CAR_1st & abnormal_return0<=CAR_99th , omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end

quietly summ CAR0to1 if citicorr<=citicorr_90th, detail
replace CAR_1st=r(p1)
replace CAR_99th=r(p99)

reg CAR0to1 geithnerschednum   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  if CAR0to1>=CAR_1st & CAR0to1<=CAR_99th & citicorr<=citicorr_90th, robust

putmata Y=CAR0to1 X=(geithnerschednum   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  constant) Err=(residbasetwo*) if CAR0to1>=CAR_1st & CAR0to1<=CAR_99th & citicorr<=citicorr_90th, omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end


reg CAR0to1 geithner2num   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  if CAR0to1>=CAR_1st & CAR0to1<=CAR_99th & citicorr<=citicorr_90th, robust

putmata Y=CAR0to1 X=(geithner2num   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  constant) Err=(residbasetwo*) if CAR0to1>=CAR_1st & CAR0to1<=CAR_99th & citicorr<=citicorr_90th, omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end

quietly summ CAR0to10 if citicorr<=citicorr_90th, detail
replace CAR_1st=r(p1)
replace CAR_99th=r(p99)

reg CAR0to10 geithnerschednum   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  if CAR0to10>=CAR_1st & CAR0to10<=CAR_99th & citicorr<=citicorr_90th, robust

putmata Y=CAR0to10 X=(geithnerschednum   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  constant) Err=(residbaseten*) if CAR0to10>=CAR_1st & CAR0to10<=CAR_99th & citicorr<=citicorr_90th, omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end


reg CAR0to10 geithner2num   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  if CAR0to10>=CAR_1st & CAR0to10<=CAR_99th & citicorr<=citicorr_90th, robust

putmata Y=CAR0to10 X=(geithner2num   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  constant) Err=(residbaseten*) if CAR0to10>=CAR_1st & CAR0to10<=CAR_99th & citicorr<=citicorr_90th, omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end





*  2007 APPOINTMENTS ONLY  (Column 13)

reg abnormal_return0 geithner07num   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  , robust


putmata Y=abnormal_return0 X=(geithner07num   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  constant) Err=(residbaseone*)  , omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end

reg CAR0to1 geithner07num   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  if  citicorr<=citicorr_90th , robust

putmata Y=CAR0to1 X=(geithner07num   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  constant) Err=(residbasetwo*)  if  citicorr<=citicorr_90th, omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end

reg CAR0to10 geithner07num   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  if  citicorr<=citicorr_90th , robust

putmata Y=CAR0to10 X=(geithner07num   ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  constant) Err=(residbaseten*) if  citicorr<=citicorr_90th , omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end



erase "Master Data.dta"
erase "merge.dta"


*  MEDIAN REGRESSIONS  (Columns 11 and 12)

* merge in personal connections data

use "Connections Data.dta", clear
gen PERSONAL_CONNECTIONS____________=.
move PERSONAL_CONNECTIONS____________ geithner2num
label var PERSONAL_CONNECTIONS____________ "_____from muckety.com

save "Master Data.dta", replace


* merge in schedule connections data

use "Schedule Data.dta", clear
sort ticker
save "Schedule Data.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Schedule Data.dta"
drop if _merge==2
drop _merge
gen SCHEDULE_CONNECTIONS____________=.
move SCHEDULE_CONNECTIONS____________ geithnerschednum
label var SCHEDULE_CONNECTIONS____________ "_____from NYT-posted schedule

save "Master Data.dta", replace


* merge in event study results

use "Event Study Output.dta", clear
sort ticker
save "Event Study Output.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Event Study Output.dta"
drop if _merge==2
drop _merge
gen GEITHNER_ANNC_RETURNS___________=.
move GEITHNER_ANNC_RETURNS___________ index_ds
label var GEITHNER_ANNC_RETURNS___________ "_____from Datastream returns

drop if ret0==. /* eliminates firms missing TAQ data */

save "Master Data.dta", replace 



* merge in financial data

use "Financial Data.dta", clear
sort ticker
save "Financial Data.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Financial Data.dta", update
drop if _merge==2
drop _merge

replace roe2008=. if roe2008>1000   /* eliminate outliers */
replace tdtc2008=. if tdtc2008<0    /* eliminate outliers */
replace ta2008=ta2008*1000          /* puts in $ terms */
replace mcap2008=mcap2008*1000      /* puts in $ terms */
gen ta2008_log=log(ta2008)
move ta2008_log roe2008
label var ta2008_log "log of ta2008
replace roe2008=roe2008/100         /* puts in percentage terms */
replace tdtc2008=tdtc2008/100       /* puts in percentage terms */

gen FINANCIAL_DATA__________________=.
move FINANCIAL_DATA__________________ name
label var FINANCIAL_DATA__________________ "_____from Worldscope

gen ny=0
replace ny=1 if addresscity_ds=="New York"
move ny SCHEDULE_CONNECTIONS____________
label var ny "dummy=1 if addresscity_ds is New York City


sort ticker
merge ticker using "citicorr.dta"
drop if _merge==2
drop _merge
label variable citicorr "return correlation with Citigroup
label variable citicorr_90th "90th percentile in Citi correlation

gen ta2008_log_sq=ta2008_log^2
gen ta2008_log_cb=(ta2008_log^3)

gen roe2008_sq=roe2008^2
gen roe2008_cb=(roe2008^3)


gen tdtc2008_sq=tdtc2008^2
gen tdtc2008_cb=(tdtc2008^3)

qreg abnormal_return0 geithnerschednum ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  
qreg abnormal_return0 geithner2num ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb 

qreg CAR0to1 geithnerschednum ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb if citicorr<=citicorr_90th 
qreg CAR0to1 geithner2num ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  if citicorr<=citicorr_90th

qreg CAR0to10 geithnerschednum ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  if citicorr<=citicorr_90th 
qreg CAR0to10 geithner2num ta2008_log ta2008_log_sq ta2008_log_cb roe2008  roe2008_sq  roe2008_cb tdtc2008  tdtc2008_sq tdtc2008_cb  if citicorr<=citicorr_90th 

