version 9.2

* This file assumes that the file "create correlations.do" has already been run. This puts correlations with Citi into an output file called "citicorr.dta".
* This file assumes that the file "create residuals.do" has already been run.  The output file "residuals.dta" allows calculation of adjusted standard errors.
* This file assumes that the file "create residuals CDS.do" has already been run. The output file "residuals CDS.dta" allows calculation of adjusted standard errors.
* This file assumes that the file "Geithner event study.do" has already been run.  This puts abnormal returns into an output file called "Event Study Output.dta".


local path "E:\Bank Crisis\"   /*insert local path of the folder used here */
cd "`path'"


* merge in CDS data

use "CDS Data.dta", clear 

*  Clean up tickers in CDS data
rename ticker ticker_markit
gen ticker=ticker_markit
replace ticker="BAC" if ticker=="BACORP"
replace ticker="FRE" if ticker=="FHLMC-New"
replace ticker="FNM" if ticker=="FNMA-New"
replace ticker="JNS" if ticker=="JANUS"
replace ticker="MS" if ticker=="MWD"
replace ticker="WU" if ticker=="WESTUN"
replace ticker="ETFC" if ticker=="ET-Fincorp"
replace ticker="AGM" if ticker=="FAMCA"
replace ticker="DRL" if ticker=="DORL"
replace ticker="DFS" if ticker=="DSF"
replace ticker="MTG" if ticker=="MGIC"
replace ticker="RF" if ticker=="RGNF"
replace ticker="SLM" if ticker=="SLMA"
replace ticker="SCHW" if ticker=="SCH"


*  Calculate changes in spreads
gen day=0 if date=="21-Nov-08"
replace day=1 if date=="24-Nov-08"
replace day=10 if date=="8-Dec-08"
keep if date=="21-Nov-08" | date=="24-Nov-08" | date=="8-Dec-08"
sort ticker day
gen spread_chg_pct1= (spread5y[_n]- spread5y[_n-1])/spread5y[_n-1] if ticker[_n]==ticker[_n-1] & day==1
gen spread_chg_pct10= (spread5y[_n+1]- spread5y[_n-1])/spread5y[_n-1] if ticker[_n+1]==ticker[_n-1] & day==1
keep if day==1
sort ticker
save "CDS Data Temp.dta", replace


* merge in personal connections data

use "Connections Data.dta", clear
gen PERSONAL_CONNECTIONS____________=.
move PERSONAL_CONNECTIONS____________ geithner2num
label var PERSONAL_CONNECTIONS____________ "_____from muckety.com

save "Master Data.dta", replace


* merge in schedule connections data

use "Schedule Data.dta", clear
sort ticker
save "Schedule Data.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Schedule Data.dta"
drop if _merge==2
drop _merge
gen SCHEDULE_CONNECTIONS____________=.
move SCHEDULE_CONNECTIONS____________ geithnerschednum
label var SCHEDULE_CONNECTIONS____________ "_____from NYT-posted schedule

save "Master Data.dta", replace


* merge in event study results

use "Event Study Output.dta", clear
sort ticker
save "Event Study Output.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Event Study Output.dta"
drop if _merge==2
drop _merge
gen GEITHNER_ANNC_RETURNS___________=.
move GEITHNER_ANNC_RETURNS___________ index_ds
label var GEITHNER_ANNC_RETURNS___________ "_____from Datastream returns

drop if ret0==. /* eliminates firms missing TAQ data */

save "Master Data.dta", replace 


* merge in financial data

use "Financial Data.dta", clear
sort ticker
save "Financial Data.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Financial Data.dta", update
drop if _merge==2
drop _merge

replace roe2008=. if roe2008>1000   /* eliminate outliers */
replace tdtc2008=. if tdtc2008<0    /* eliminate outliers */
replace ta2008=ta2008*1000          /* puts in $ terms */
replace mcap2008=mcap2008*1000      /* puts in $ terms */
gen ta2008_log=log(ta2008)
move ta2008_log roe2008
label var ta2008_log "log of ta2008
replace roe2008=roe2008/100         /* puts in percentage terms */
replace tdtc2008=tdtc2008/100       /* puts in percentage terms */

gen FINANCIAL_DATA__________________=.
move FINANCIAL_DATA__________________ name
label var FINANCIAL_DATA__________________ "_____from Worldscope

gen ny=0
replace ny=1 if addresscity_ds=="New York"
move ny SCHEDULE_CONNECTIONS____________
label var ny "dummy=1 if addresscity_ds is New York City


sort ticker
merge ticker using "citicorr.dta"
drop if _merge==2
drop _merge
label variable citicorr "return correlation with Citigroup
label variable citicorr_90th "90th percentile in Citi correlation
sort ticker
merge ticker using "residuals.dta"
drop if _merge==2
drop _merge

sort ticker
merge ticker using "CDS Data Temp.dta"

drop _merge
sort ticker
gen constant=1

gen ta2008_log_sq=ta2008_log^2
gen ta2008_log_cb=(ta2008_log^3)

gen roe2008_sq=roe2008^2
gen roe2008_cb=(roe2008^3)


gen tdtc2008_sq=tdtc2008^2
gen tdtc2008_cb=(tdtc2008^3)


reg CAR0to1 geithner2num ta2008_log roe2008 tdtc2008 ta2008_log_sq ta2008_log_cb  roe2008_sq roe2008_cb  tdtc2008_sq tdtc2008_cb  if ~(citicorr==1)

putmata Y=CAR0to1 X=(geithner2num ta2008_log roe2008 tdtc2008 ta2008_log_sq ta2008_log_cb  roe2008_sq roe2008_cb  tdtc2008_sq tdtc2008_cb  constant) Err=(residbasetwo*) if ~(citicorr==1), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end


reg CAR0to1 geithner2num summers2num corzine2num volcker2num bair2num ta2008_log roe2008 tdtc2008 ta2008_log_sq ta2008_log_cb  roe2008_sq roe2008_cb  tdtc2008_sq tdtc2008_cb  if ~(citicorr==1)
putmata Y=CAR0to1 X=(geithner2num summers2num corzine2num volcker2num bair2num ta2008_log roe2008 tdtc2008 ta2008_log_sq ta2008_log_cb  roe2008_sq roe2008_cb  tdtc2008_sq tdtc2008_cb  constant) Err=(residbasetwo*) if ~(citicorr==1), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end

gen total2num=0
replace total2num=summers2num+corzine2num+volcker2num+bair2num

reg CAR0to1 geithner2num total2num ta2008_log roe2008 tdtc2008 ta2008_log_sq ta2008_log_cb  roe2008_sq roe2008_cb  tdtc2008_sq tdtc2008_cb  if ~(citicorr==1)
putmata Y=CAR0to1 X=(geithner2num total2num ta2008_log roe2008 tdtc2008 ta2008_log_sq ta2008_log_cb  roe2008_sq roe2008_cb  tdtc2008_sq tdtc2008_cb  constant) Err=(residbasetwo*) if ~(citicorr==1), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
drop resid*

sort ticker
merge ticker using "residuals CDS.dta"
drop if _merge==2
drop _merge


reg  spread_chg_pct1  geithner2num ta2008_log roe2008 tdtc2008 ta2008_log_sq ta2008_log_cb  roe2008_sq roe2008_cb  tdtc2008_sq tdtc2008_cb  

putmata Y=spread_chg_pct1 X=(geithner2num ta2008_log roe2008 tdtc2008 ta2008_log_sq ta2008_log_cb  roe2008_sq roe2008_cb  tdtc2008_sq tdtc2008_cb  constant) Err=(residbaseone*) , omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end



reg  spread_chg_pct1  geithner2num summers2num corzine2num volcker2num ta2008_log roe2008 tdtc2008 ta2008_log_sq ta2008_log_cb  roe2008_sq roe2008_cb  tdtc2008_sq tdtc2008_cb  

putmata Y=spread_chg_pct1 X=(geithner2num summers2num corzine2num volcker2num ta2008_log roe2008 tdtc2008 ta2008_log_sq ta2008_log_cb  roe2008_sq roe2008_cb  tdtc2008_sq tdtc2008_cb  constant) Err=(residbaseone*) , omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end

reg  spread_chg_pct1  geithner2num total2num ta2008_log roe2008 tdtc2008 ta2008_log_sq ta2008_log_cb  roe2008_sq roe2008_cb  tdtc2008_sq tdtc2008_cb  

putmata Y=spread_chg_pct1 X=(geithner2num total2num ta2008_log roe2008 tdtc2008 ta2008_log_sq ta2008_log_cb  roe2008_sq roe2008_cb  tdtc2008_sq tdtc2008_cb  constant) Err=(residbaseone*) , omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end

drop constant resid*
erase "CDS Data Temp.dta"
erase "Master Data.dta"





