version 9.2

* This file assumes that the file "create correlations.do" has already been run. This puts correlations with Citi into an output file called "citicorr.dta".
* This file assumes that the file "create residuals.do" has already been run. The output file "residuals.dta" allows calculation of adjusted standard errors.
* This file assumes that the file "Geithner event study.do" has already been run.  This puts abnormal returns into an output file called "Event Study Output.dta".


local path "E:\Bank Crisis\"   /*insert local path of the folder used here */
cd "`path'"


* merge in financial data

use "LT Financial Data.dta", clear
sort ticker
save "LT Financial Data.dta", replace


save "Master Data.dta", replace

* merge in personal connections data

use "Connections Data.dta", clear
sort ticker
save "Connections Data.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Connections Data.dta", update
drop if _merge==2
drop _merge

gen PERSONAL_CONNECTIONS____________=.
move PERSONAL_CONNECTIONS____________ geithner2num
label var PERSONAL_CONNECTIONS____________ "_____from muckety.com

save "Master Data.dta", replace


* merge in schedule connections data

use "Schedule Data.dta", clear
sort ticker
save "Schedule Data.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Schedule Data.dta"
drop if _merge==2
drop _merge
gen SCHEDULE_CONNECTIONS____________=.
move SCHEDULE_CONNECTIONS____________ geithnerschednum
label var SCHEDULE_CONNECTIONS____________ "_____from NYT-posted schedule

save "Master Data.dta", replace


* merge in event study results

use "Event Study Output.dta", clear
sort ticker
save "Event Study Output.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Event Study Output.dta"
drop if _merge==2
drop _merge
gen GEITHNER_ANNC_RETURNS___________=.
move GEITHNER_ANNC_RETURNS___________ index_ds
label var GEITHNER_ANNC_RETURNS___________ "_____from Datastream returns

drop if ret0==. /* eliminates firms missing TAQ data */

save "Master Data.dta", replace 



* merge in financial data

use "Financial Data.dta", clear
sort ticker
save "Financial Data.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Financial Data.dta", update
drop if _merge==2
drop _merge

replace roe2008=. if roe2008>1000   /* eliminate outliers */
replace tdtc2008=. if tdtc2008<0    /* eliminate outliers */
replace ta2008=ta2008*1000          /* puts in $ terms */
replace mcap2008=mcap2008*1000      /* puts in $ terms */
gen ta2008_log=log(ta2008)
move ta2008_log roe2008
label var ta2008_log "log of ta2008
replace roe2008=roe2008/100         /* puts in percentage terms */
replace tdtc2008=tdtc2008/100       /* puts in percentage terms */

gen FINANCIAL_DATA__________________=.
move FINANCIAL_DATA__________________ name
label var FINANCIAL_DATA__________________ "_____from Worldscope

gen ny=0
replace ny=1 if addresscity_ds=="New York"
move ny SCHEDULE_CONNECTIONS____________
label var ny "dummy=1 if addresscity_ds is New York City


sort ticker
merge ticker using "citicorr.dta"
drop if _merge==2
drop _merge
label variable citicorr "return correlation with Citigroup
label variable citicorr_90th "90th percentile in Citi correlation


gen ta2008_log_sq=ta2008_log^2
gen ta2008_log_cb=(ta2008_log^3)

gen roe2008_sq=roe2008^2
gen roe2008_cb=(roe2008^3)


gen tdtc2008_sq=tdtc2008^2
gen tdtc2008_cb=(tdtc2008^3)

gen geithneryear=0
replace geithneryear=1 if fyear==2009 | fyear==2010
gen geithnerbefore=0
replace geithnerbefore=1 if fyear==2007 | fyear==2008 | fyear==2006 | fyear==2005
gen geithnerafter=0
replace geithnerafter=1 if fyear==2011 | fyear==2012 | fyear==2013 | fyear==2014

replace txdb=0 if txdb==.
replace mib=0 if mib==.
replace pstk=0 if pstk==.

gen roe=ebitda/seq
gen roa=ebitda/at
gen tobinsq=((csho*PRCC_C)+lt)/(seq+lt)

gen logat=log(at)
gen logatsq=logat^2
gen logatcb=logat^3

gen td2tc=lt/(lt+seq+pstk+mib+txdb)
gen td2tcsq=td2tc^2
gen td2tccb=td2tc^3



replace tobinsq=log(tobinsq)

gen schedXyear=geithnerschednum*geithneryear
gen persXyear=geithner2num*geithneryear
gen nyXyear=ny*geithneryear

gen schedXbefore=geithnerschednum*geithnerbefore
gen persXbefore=geithner2num*geithnerbefore
gen nyXbefore=ny*geithnerbefore

gen schedXafter=geithnerschednum*geithnerafter
gen persXafter=geithner2num*geithnerafter
gen nyXafter=ny*geithnerafter



areg roe  schedXbefore schedXyear schedXafter logat logatsq logatcb td2tc td2tcsq td2tccb, absorb(fyear) cluster(ticker)
areg roe  persXbefore persXyear persXafter logat logatsq logatcb td2tc td2tcsq td2tccb, absorb(fyear) cluster(ticker)
areg roe  nyXbefore nyXyear nyXafter logat logatsq logatcb td2tc td2tcsq td2tccb , absorb(fyear) cluster(ticker)

areg tobinsq  schedXbefore schedXyear schedXafter logat logatsq logatcb td2tc td2tcsq td2tccb , absorb(fyear) cluster(ticker)
areg tobinsq  persXbefore persXyear persXafter logat logatsq logatcb td2tc td2tcsq td2tccb , absorb(fyear) cluster(ticker)
areg tobinsq  nyXbefore nyXyear nyXafter logat logatsq logatcb td2tc td2tcsq td2tccb , absorb(fyear) cluster(ticker)

