version 9.2

* This file assumes that the file "Geithner event study.do" has already been run.  This puts abnormal returns into an output file called "Event Study Output.dta".
* This file assumes that the file "Geithner event study Lehman.do" has already been run.  This puts abnormal returns surrounding Lehman collapse into an output file called "Event Study Output Lehman.dta".


local path "E:\Bank Crisis\"   /*insert local path of the folder used here */
cd "`path'"


use "Event Study Output Lehman.dta", clear
keep ticker CAR0to4

rename CAR0to4 CAR0to4_lmn


sort ticker
save "merge.dta", replace


* merge in personal connections data

use "Connections Data.dta", clear
gen PERSONAL_CONNECTIONS____________=.
move PERSONAL_CONNECTIONS____________ geithner2num
label var PERSONAL_CONNECTIONS____________ "_____from muckety.com

save "Master Data.dta", replace


* merge in schedule connections data

use "Schedule Data.dta", clear
sort ticker
save "Schedule Data.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Schedule Data.dta"
drop if _merge==2
drop _merge
gen SCHEDULE_CONNECTIONS____________=.
move SCHEDULE_CONNECTIONS____________ geithnerschednum
label var SCHEDULE_CONNECTIONS____________ "_____from NYT-posted schedule

save "Master Data.dta", replace


* merge in TARP data

use "TARP Data.dta", clear
sort ticker
save "TARP Data.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "TARP Data.dta"
drop if _merge==2
drop _merge
gen TARP_DATA_______________________=.
move  TARP_DATA_______________________ footnote_tarp
label var TARP_DATA_______________________ "_____from US Treasury Dept.
replace amount_tarp=0 if amount_tarp==.
drop if footnote_tarp==0     /* this gets rid of multiple tarp funding dates */

save "Master Data.dta", replace


* merge in event study results

use "Event Study Output.dta", clear
sort ticker
save "Event Study Output.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Event Study Output.dta"
drop if _merge==2
drop _merge
gen GEITHNER_ANNC_RETURNS___________=.
move GEITHNER_ANNC_RETURNS___________ index_ds
label var GEITHNER_ANNC_RETURNS___________ "_____from Datastream returns

drop if ret0==. /* eliminates firms missing TAQ data */

save "Master Data.dta", replace 


* merge in financial data

use "Financial Data.dta", clear
sort ticker
save "Financial Data.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Financial Data.dta", update
drop if _merge==2
drop _merge

replace roe2008=. if roe2008>1000   /* eliminate outliers */
replace tdtc2008=. if tdtc2008<0    /* eliminate outliers */
replace ta2008=ta2008*1000          /* puts in $ terms */
replace mcap2008=mcap2008*1000      /* puts in $ terms */
gen ta2008_log=log(ta2008)
move ta2008_log roe2008
label var ta2008_log "log of ta2008
replace roe2008=roe2008/100         /* puts in percentage terms */
replace tdtc2008=tdtc2008/100       /* puts in percentage terms */

gen FINANCIAL_DATA__________________=.
move FINANCIAL_DATA__________________ name
label var FINANCIAL_DATA__________________ "_____from Worldscope

gen ny=0
replace ny=1 if addresscity_ds=="New York"
move ny SCHEDULE_CONNECTIONS____________
label var ny "dummy=1 if addresscity_ds is New York City


save "Master Data.dta", replace

sort ticker
merge ticker using "merge.dta"
drop if _merge==2
drop _merge


* Create dummies from connections variables

gen geithnersched=0
replace geithnersched=1 if geithnerschednum>0
gen geithner2=0
replace geithner2=1 if geithner2num>0

* Create additional control variables

gen statadate_tarp=date(datestring_tarp,"md20y")
gen tarpbefore=0
replace tarpbefore=1 if ~(amount_tarp==0) & statadate_tarp<17857 & ~(statadate_tarp==.) /* dummy for if firm had received TARP funding prior to nomination */

gen dep=0
replace dep=1 if  tdep2ta2008>0 &~( tdep2ta2008==.)
replace dep=1 if dep==0 &  tdep2ta2007>0 &~( tdep2ta2007==.) & ~( tdep2ta2008==0)  /*  dummy for if the firm takes deposits */


psmatch2 geithnersched ta2008_log ,        norepl  outcome(CAR0to1)
pstest ta2008_log 
psmatch2 geithner2 ta2008_log ,        norepl  outcome(CAR0to1)
pstest ta2008_log 
psmatch2 ny ta2008_log  ,        norepl  outcome(CAR0to1)
pstest ta2008_log 


psmatch2 geithnersched ta2008_log  ,         norepl  outcome(CAR0to10)
psmatch2 geithner2 ta2008_log  ,        norepl  outcome(CAR0to10)
psmatch2 ny ta2008_log  ,        norepl  outcome(CAR0to10)

psmatch2 geithnersched ta2008_log roe2008 tdtc2008 ,        norepl  outcome(CAR0to1)
pstest ta2008_log roe2008 tdtc2008 
psmatch2 geithner2 ta2008_log roe2008 tdtc2008  ,        norepl  outcome(CAR0to1)
pstest ta2008_log roe2008 tdtc2008 
psmatch2 ny ta2008_log roe2008 tdtc2008  ,        norepl  outcome(CAR0to1)
pstest ta2008_log roe2008 tdtc2008 


psmatch2 geithnersched ta2008_log roe2008 tdtc2008 ,         norepl  outcome(CAR0to10)
psmatch2 geithner2 ta2008_log roe2008 tdtc2008 ,        norepl  outcome(CAR0to10)
psmatch2 ny ta2008_log roe2008  tdtc2008 ,        norepl  outcome(CAR0to10)


psmatch2 geithnersched ta2008_log roe2008 tdtc2008 dep CAR0to4_lmn tarpbefore,        norepl  outcome(CAR0to1)
pstest ta2008_log roe2008  tdtc2008 dep CAR0to4_lmn tarpbefore
psmatch2 geithner2 ta2008_log roe2008 tdtc2008 dep CAR0to4_lmn tarpbefore,        norepl  outcome(CAR0to1)
pstest ta2008_log roe2008  tdtc2008 dep CAR0to4_lmn tarpbefore
psmatch2 ny ta2008_log roe2008 tdtc2008 dep CAR0to4_lmn tarpbefore,        norepl  outcome(CAR0to1)
pstest ta2008_log roe2008  tdtc2008 dep CAR0to4_lmn tarpbefore


psmatch2 geithnersched ta2008_log roe2008 tdtc2008 dep CAR0to4_lmn tarpbefore,         norepl  outcome(CAR0to10)
psmatch2 geithner2 ta2008_log roe2008 tdtc2008 dep CAR0to4_lmn tarpbefore,        norepl  outcome(CAR0to10)
psmatch2 ny ta2008_log roe2008  tdtc2008 dep CAR0to4_lmn tarpbefore,        norepl  outcome(CAR0to10)




