version 9.2

* This file calculates abnormal changes in CDS spreads for the estimation window in order to the create pre-event correlation matrix (sigma)
* Output goes into a file "residuals CDS.dta"


local path "E:\Bank Crisis\"   /*insert local path of the folder used here */
cd "`path'"


set more off

use "CDS Data.dta", clear
rename ticker ticker_markit
gen ticker=ticker_markit
replace ticker="BAC" if ticker=="BACORP"
replace ticker="FRE" if ticker=="FHLMC-New"
replace ticker="FNM" if ticker=="FNMA-New"
replace ticker="JNS" if ticker=="JANUS"
replace ticker="MS" if ticker=="MWD"
replace ticker="WU" if ticker=="WESTUN"
replace ticker="ETFC" if ticker=="ET-Fincorp"
replace ticker="AGM" if ticker=="FAMCA"
replace ticker="DRL" if ticker=="DORL"
replace ticker="DFS" if ticker=="DSF"
replace ticker="MTG" if ticker=="MGIC"
replace ticker="RF" if ticker=="RGNF"
replace ticker="SLM" if ticker=="SLMA"
replace ticker="SCHW" if ticker=="SCH"
*keep if ccy=="USD"
*keep if docclause=="MR"
*keep if tier=="SNRFOR"
gen day=0 if date=="21-Nov-08"
gen statadate=date(date,"dm20y")

sort ticker statadate

gen spreadone= (spread5y[_n]- spread5y[_n-1])/spread5y[_n-1] if ticker[_n]==ticker[_n-1]

gen spreadten= (spread5y[_n+9]- spread5y[_n-1])/spread5y[_n-1] if ticker[_n+9]==ticker[_n-1]

sort ticker statadate

gen event_date=17857  /* 17857 is Nov 21, 2008: Geithner nomination first leaked */


* create difference from event date

sort ticker statadate
by ticker: gen datenum=_n
by ticker: gen target=datenum if statadate==event_date
egen td=min(target), by(ticker)
drop target
gen dif=datenum-td
drop datenum td


* choose event window and estimation window

by ticker: gen event_window=1 if dif>=0 & dif<=10 & ~(spreadone==.)
egen count_event_obs=count(event_window), by(ticker)
by ticker: gen estimation_window=1 if dif>=-280 & dif<-30 & ~(spreadone==.)
egen count_est_obs=count(estimation_window), by(ticker)


* prepare output for merging with master file

drop if estimation_window==.
drop  event_window count_event_obs estimation_window count_est_obs spread5y 

replace dif=-dif

reshape wide statadate date  spreadone spreadten, i(ticker) j(dif)


sort ticker
save "residuals CDS.dta", replace
use "Financial Data.dta", clear
sort ticker
save "Financial Data.dta", replace
use "residuals CDS.dta", clear
sort ticker
merge ticker using "Financial Data.dta", update
drop if _merge==2
drop _merge

replace roe2008=. if roe2008>1000   /* eliminate outliers */
replace tdtc2008=. if tdtc2008<0    /* eliminate outliers */
replace ta2008=ta2008*1000          /* puts in $ terms */
replace mcap2008=mcap2008*1000      /* puts in $ terms */
gen ta2008_log=log(ta2008)
move ta2008_log roe2008
label var ta2008_log "log of ta2008
replace roe2008=roe2008/100         /* puts in percentage terms */
replace tdtc2008=tdtc2008/100       /* puts in percentage terms */


*   This one uses one-day returns, w/o Citi
forvalues i=280(-1)32 {

 reg spreadone`i'  ta2008_log roe2008 tdtc2008 if ~(ticker=="C")
predict residbaseone`i', residuals
replace residbaseone`i'=0 if residbaseone`i'==.
}

 
*   This one uses one-day returns, w/ Citi
forvalues i=280(-1)32 {

reg spreadone`i'  ta2008_log roe2008 tdtc2008
predict residfullone`i', residuals
replace residfullone`i'=0 if residfullone`i'==.
}


* This one uses ten-day returns, w/o Citi

forvalues i=280(-1)41 {

reg spreadten`i'  ta2008_log roe2008 tdtc2008 if ~(ticker=="C")
predict residbaseten`i', residuals
replace residbaseten`i'=0 if residbaseten`i'==.
}


* This one uses ten-day returns, w/ Citi

forvalues i=280(-1)41 {

reg spreadten`i'  ta2008_log roe2008 tdtc2008
predict residfullten`i', residuals
replace residfullten`i'=0 if residfullten`i'==.
}


sort ticker
save "residuals CDS.dta", replace
